@@ -70,7 +70,7 @@ opt_parser.add_option('--no-cairo-widgets', action='store_true',
     help=_("Do not use the cairo version of input widgets, even if we run gtk+ 2.8.0 or newer."))
 opt_parser.add_option('--show-gtk-warnings', action='store_true',
     dest='show_gtk_warnings',
-    help=_('Show GtkWarnings in the traceback window.'))
+    help=_('Show GtkWarnings and PangoWarnings in the traceback window.'))
 
 
 options, args = opt_parser.parse_args()
@@ -335,6 +335,7 @@ class MainWin(App, cfg.ConfigUtils):
           ('HelpMenu', None, _('_Help')),
           ('HelpHelp', 'gtk-help', _('_Help on current exercise'), 'F1', None,
             lambda o: self.m_app.please_help_me()),
+          ('HelpTheory', None, _('_Show music theory about the current exercise'), 'F3', None, lambda o: self.m_app.show_exercise_theory()),
           ('HelpIndex', None, _('_User manual'), None, None,
             lambda o: self.m_app.handle_href('index.html')),
           ('HelpAllLessonFiles', None, _('All installed _lesson files'), None,
@@ -378,15 +379,21 @@ class MainWin(App, cfg.ConfigUtils):
             )]
         if self.m_app.m_options.debug:
             actions = [('LearningTreesMenu', None, _('Learning tree')),
-                ('DefaultTree', None, _("Debugging"),
-                None, None,
-               lambda o: self.change_learning_tree(self.debug_learning_tree)
+                ('DefaultTree', None, _("Default learning tree"),
+                 None, None,
+                 lambda o: self.change_learning_tree(self.default_learning_tree)
+                ),
+                ('DebuggingTree', None, _("Debugging"),
+                 None, None,
+                 lambda o: self.change_learning_tree(self.debug_learning_tree)
                 )]
         s = """
 <menubar name='Menubar'>
  <menu action='FileMenu'>
   <menu action='LearningTreesMenu' position='top'>
     <menuitem action='DefaultTree'/>"""
+        if self.m_app.m_options.debug:
+            s += "<menuitem action='DebuggingTree'/>"
         for tree_fn in v:
             s += "<menuitem action='LTree-%s'/>" % tree_fn
             actions.append(('LTree-%s' % tree_fn, None,
@@ -451,21 +458,24 @@ class MainWin(App, cfg.ConfigUtils):
         self.m_practise_and_test_merge_id = self.g_ui_manager.add_ui_from_string(s)
     def show_help_on_current(self):
         """
-        Show the "Help on current exercise F1" menu entry on the
-        Help menu.
+        Show the menu entries for the exercise help and music theory
+        pages on the Help menu.
         """
         if self.m_help_on_current_merge_id:
             return
         self.m_help_on_current_merge_id = self.g_ui_manager.add_ui_from_string("""
 <menubar name='Menubar'>
   <menu action='HelpMenu'>
-    <menuitem position='top' action='HelpHelp' />
+    <placeholder name='PerExerciseHelp'>
+      <menuitem position='top' action='HelpHelp' />
+      <menuitem action='HelpTheory' />
+    </placeholder>
   </menu>
 </menubar>""")
     def hide_help_on_current(self):
         """
-        Hide the "Help on current exercise F1" menu entry on
-        the Help menu.
+        Hide the menu entries for the help and music theory pages on the
+        Help menu.
         """
         if not self.m_help_on_current_merge_id:
             return
